@@ -112,7 +112,7 @@ def grab_key_from_pongo(img_file: str):
     print("[i] grabbing keys from PongoOS device")
     kbag = decrypt_img.get_kbag(img_file)
     print("[i] kbag : {}".format(kbag))
-    pongo.pongo_send_command(f"sep decrypt {kbag}")
+    pongo.pongo_send_command(f"aes cbc dec 256 gid0 {kbag}")
     ivkey = pongo.pongo_get_key()
     return ivkey
 
@@ -161,7 +161,7 @@ def main():
     if parser.pongo is True:
         ivkey = grab_key_from_pongo(parser.img_file)
 
-    if ivkey is None and parser.ip_addr is None:
+    if ivkey is None and parser.ip_addr is None and parser.pongo is False:
         ivkey = get_firmware_keys(parser.device, build,
                                   parser.img_file, image_type)
 
