@@ -19,5 +19,5 @@ def pongo_get_key() -> str:
         return None
     dev.set_configuration()
     output = dev.ctrl_transfer(0xa1, 1, 0, 0, 512).tobytes()
-    key = output.decode('utf-8').split('\n')[1]
+    key = output.decode('utf-8').split()[-2]
     return key
